<?php
/**
 * GutenStart functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package GutenStart
 */

if ( ! function_exists( 'gutenstart_setup' ) ) :
	function gutenstart_setup() {
		// Make theme available for translation.
		load_theme_textdomain( 'gutenstart', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'gutenstart' ),
		) );

		// Switch default core markup to output valid HTML5.
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'gutenstart_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add theme support for responsive embeds
		add_theme_support( 'responsive-embeds' );

		// Add support for core custom logo.
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		add_image_size( 'gutenstart-featured-image', 1200, 600, true );

		// Add support for wide blocks in block editor if sidebar is hidden
		if ( get_theme_mod( 'gutenstart_sidebar_position', 'hide' ) === 'hide' ) {
			add_theme_support( 'align-wide' );
		}

		// Starter Content
		$gutenstart_starter_content = array(
			'options' => array(
				'gutenstart_display_cover_section' => true,
				'gutenstart_cover_img'             => get_template_directory_uri() . '/assets/images/cover-img.jpg',
				'gutenstart_cover_title'           => __( 'Create A Beautiful Blog Easily.', 'gutenstart' ),
				'gutenstart_cover_subtitle'        => __( 'GutenStart is a simple and easy to use blog theme. It is designed and developed primarily to create professional blogging websites with Gutenberg editor.', 'gutenstart' ),
			),
		);
		add_theme_support( 'starter-content', $gutenstart_starter_content );

	}
endif;
add_action( 'after_setup_theme', 'gutenstart_setup' );



/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 */
function gutenstart_content_width() {
	// This variable is intended to be overruled from themes.
	$GLOBALS['content_width'] = apply_filters( 'gutenstart_content_width', 780 );
}
add_action( 'after_setup_theme', 'gutenstart_content_width', 0 );



/**
 * Register widget area.
 */
function gutenstart_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'gutenstart' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'gutenstart' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title h4">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'gutenstart_widgets_init' );



/**
 * Enqueue scripts and styles.
 */
function gutenstart_scripts() {
	wp_enqueue_style( 'bootstrap-grid', get_template_directory_uri() . '/assets/css/bootstrap-grid.css', array(), 'v4.4.1', 'all' );
	wp_enqueue_style( 'gutenstart-style', get_stylesheet_uri(), array(), '1.0.3', 'all'  );

	wp_enqueue_script( 'gutenstart-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'gutenstart-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );
	wp_enqueue_script( 'gutenstart-theme', get_template_directory_uri() . '/assets/js/theme.js', array('jquery'), '1.0.3', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gutenstart_scripts' );



/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}



// Implement the Custom Header feature.
require get_template_directory() . '/inc/custom-header.php';

// Custom template tags for this theme.
require get_template_directory() . '/inc/template-tags.php';

// Functions which enhance the theme by hooking into WordPress.
require get_template_directory() . '/inc/template-functions.php';

// Customizer additions.
require get_template_directory() . '/inc/customizer.php';
