<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package GutenStart
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">

	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'gutenstart' ); ?></a>

	<?php
	if ( has_header_image() ) {
		if ( get_theme_mod( 'gutenstart_display_header_img_only_on_home', true ) ) {
			if ( is_home() ) {
				the_custom_header_markup();
			}
		}
		else {
			the_custom_header_markup();
		}
	}
	?>

	<header id="masthead" class="site-header">
		<div class="container">
			<div class="row align-items-center">
				<div class="col-md-3">
					<div class="site-branding">
						<?php
						the_custom_logo();
						if ( is_front_page() && is_home() ) :
							?>
							<h1 class="site-title h1"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php
						else :
							?>
							<p class="site-title h1"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
						endif;
						$gutenstart_description = get_bloginfo( 'description', 'display' );
						if ( $gutenstart_description || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo esc_html( $gutenstart_description ); ?></p>
						<?php endif; ?>
					</div><!-- .site-branding -->
				</div>
				<!-- /.col-md-3 -->

				<div class="col-md-9 text-right">
					<nav id="site-navigation" class="main-navigation">
						<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e( 'Primary Menu', 'gutenstart' ); ?></button>
						<?php
						wp_nav_menu( array(
							'theme_location' => 'menu-1',
							'menu_id'        => 'primary-menu',
						) );
						?>
					</nav><!-- #site-navigation -->
				</div>
				<!-- /.col-md-9 -->
				</div>
			<!-- /.row -->
		</div>
		<!-- /.container -->

	</header><!-- #masthead -->

	<div id="content" class="site-content">
		<div class="container">
