<?php

// Add Section
$wp_customize->add_section( 'gutenstart_theme_general_settings', array(
	'title'    => __( 'Theme Options', 'gutenstart' ),
	'priority' => 30,
) );

// Logo hight setting
$wp_customize->add_setting( 'gutenstart_logo_height', array(
	'default'           => 60,
	'sanitize_callback' => 'absint',
) );
$wp_customize->add_control( 'gutenstart_logo_height', array(
	'label'    => __( 'Enter logo height (in px)', 'gutenstart' ),
	'type'     => 'number',
	'section'  => 'title_tagline',
	'setting'  => 'gutenstart_logo_height',
	'priority' => '9',
) );


// Sidebar Setting
$wp_customize->add_setting( 'gutenstart_sidebar_position', array(
	'default'           => 'hide',
	'sanitize_callback' => 'gutenstart_sanitize_select',
) );
$wp_customize->add_control( 'gutenstart_sidebar_position', array(
	'label'   => __( 'Sidebar Position', 'gutenstart' ),
	'type'    => 'select',
	'section' => 'gutenstart_theme_general_settings',
	'setting' => 'gutenstart_sidebar_position',
	'choices' => array(
        'hide'  => __( 'Hide Sidebar (Default)', 'gutenstart' ),
        'right' => __( 'Right', 'gutenstart' ),
        'left'  => __( 'Left', 'gutenstart' ),
	  )
) );


// Display full blog post
$wp_customize->add_setting( 'gutenstart_display_full_blog', array(
	'default'           => false,
	'sanitize_callback' => 'gutenstart_sanitize_checkbox',
) );
$wp_customize->add_control( 'gutenstart_display_full_blog', array(
	'label'       => __( 'Display full posts on the Homepage', 'gutenstart' ),
	'type'        => 'checkbox',
	'section'     => 'gutenstart_theme_general_settings',
	'setting'     => 'gutenstart_display_full_blog',
	'description' => esc_html__( 'By default, excerpt is displayed on the blog homepage.', 'gutenstart' ),
) );


// Display header image on all pages
$wp_customize->add_setting( 'gutenstart_display_header_img_only_on_home', array(
	'default'           => true,
	'sanitize_callback' => 'gutenstart_sanitize_checkbox',
) );
$wp_customize->add_control( 'gutenstart_display_header_img_only_on_home', array(
	'label'           => __( 'Display header image only on the Homepage', 'gutenstart' ),
	'type'            => 'checkbox',
	'section'         => 'gutenstart_theme_general_settings',
	'setting'         => 'gutenstart_display_header_img_only_on_home',
	'description'     => esc_html__( 'By default, header image is displayed on all pages.', 'gutenstart' ),
	'active_callback' => 'gutenstart_is_custom_header_active',
) );


// Hide goto top button
$wp_customize->add_setting( 'gutenstart_hide_goto_top', array(
	'default'           => false,
	'sanitize_callback' => 'gutenstart_sanitize_checkbox',
) );
$wp_customize->add_control( 'gutenstart_hide_goto_top', array(
	'label'       => __( 'Hide "Goto Top" button from footer', 'gutenstart' ),
	'type'        => 'checkbox',
	'section'     => 'gutenstart_theme_general_settings',
	'setting'     => 'gutenstart_hide_goto_top',
	'description' => esc_html__( 'By default, it will be displayed when user scrolls down more than 700 px.', 'gutenstart' ),
) );


// Display cover section on homepage
$wp_customize->add_setting( 'gutenstart_display_cover_section', array(
	'default'           => false,
	'sanitize_callback' => 'gutenstart_sanitize_checkbox',
) );
$wp_customize->add_control( 'gutenstart_display_cover_section', array(
	'label'             => __( 'Display cover section on Homepage', 'gutenstart' ),
	'type'              => 'checkbox',
	'section'           => 'gutenstart_theme_general_settings',
	'setting'           => 'gutenstart_display_cover_section',
	'description'       => esc_html__( 'Uncheck this setting if you want to hide cover section from the blog homepage.', 'gutenstart' ),
) );


// Cover Image
$wp_customize->add_setting('gutenstart_cover_img', array(
    'default'           => get_template_directory_uri() . '/assets/images/cover-img.jpg',
	'sanitize_callback' => 'gutenstart_sanitize_image',
));
$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'gutenstart_cover_img', array(
    'label'           => __('Cover Section Image', 'gutenstart'),
    'section'         => 'gutenstart_theme_general_settings',
    'setting'         => 'gutenstart_cover_img',
	'active_callback' => 'gutenstart_is_cover_active',
)));


// Cover Title
$wp_customize->add_setting( 'gutenstart_cover_title', array(
	'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( 'gutenstart_cover_title', array(
	'label'           => __( 'Title on Cover Section', 'gutenstart' ),
	'type'            => 'text',
	'section'         => 'gutenstart_theme_general_settings',
	'setting'         => 'gutenstart_cover_title',
	'active_callback' => 'gutenstart_is_cover_active',
) );
$wp_customize->get_setting( 'gutenstart_cover_title' )->transport = 'postMessage';


// Cover subtitle
$wp_customize->add_setting( 'gutenstart_cover_subtitle', array(
	'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( 'gutenstart_cover_subtitle', array(
	'label'           => __( 'Sub-title on Cover Section', 'gutenstart' ),
	'type'            => 'textarea',
	'section'         => 'gutenstart_theme_general_settings',
	'setting'         => 'gutenstart_cover_subtitle',
	'active_callback' => 'gutenstart_is_cover_active',
) );
$wp_customize->get_setting( 'gutenstart_cover_subtitle' )->transport = 'postMessage';


function gutenstart_sanitize_select( $input, $setting ){

	//input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
	$input = sanitize_key($input);

	//get the list of possible select options
	$choices = $setting->manager->get_control( $setting->id )->choices;

	//return input if valid or return default option
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}


function gutenstart_sanitize_checkbox( $checked ){

	//returns true if checkbox is checked
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}
